@@ -13,7 +13,7 @@
 from ibm_botocore.compat import OrderedDict
 
 
-class BaseDocumenter(object):
+class BaseDocumenter:
     def __init__(self, resource):
         self._resource = resource
         self._client = self._resource.meta.client
@@ -24,8 +24,9 @@ class BaseDocumenter(object):
         self._service_docs_name = self._client.__class__.__name__
         self.member_map = OrderedDict()
         self.represents_service_resource = (
-            self._service_name == self._resource_name)
+            self._service_name == self._resource_name
+        )
 
     @property
     def class_name(self):
-        return '%s.%s' % (self._service_docs_name, self._resource_name)
+        return f'{self._service_docs_name}.{self._resource_name}'
